@@ -421,9 +421,14 @@ postgres_docs_keywords = [
     ("JSON_OBJECT", "not-keyword"),
     ("JSON_OBJECTAGG", "not-keyword"),
     ("JSON_QUERY", "not-keyword"),
+    ("JSON_SERIALIZE", "not-keyword"),
     ("JSON_TABLE", "not-keyword"),
     ("JSON_TABLE_PRIMITIVE", "not-keyword"),
     ("JSON_VALUE", "not-keyword"),
+    ("JSONB_EACH", "not-keyword"),
+    ("JSONB_EACH_TEXT", "not-keyword"),
+    ("JSON_EACH", "not-keyword"),
+    ("JSON_EACH_TEXT", "not-keyword"),
     ("JSONB", "non-reserved-(cannot-be-function-or-type)"),
     ("K", "not-keyword"),
     ("KEEP", "not-keyword"),
