@@ -406,6 +406,7 @@ FUTURE_RESERVED_KEYWORDS = [
     "RELATIVE",
     "RELEASE",
     "RESULT",
+    "RETURNING",
     "RETURNS",
     "ROLE",
     "ROLLUP",
@@ -472,6 +473,7 @@ FUTURE_RESERVED_KEYWORDS = [
     "WITHIN",
     "WITHOUT",
     "WORK",
+    "WRAPPER",
     "WRITE",
     "XMLAGG",
     "XMLATTRIBUTES",
@@ -502,6 +504,7 @@ UNRESERVED_KEYWORDS = [
     "ABSENT",
     "ACCELERATED_DATABASE_RECOVERY",
     "ACCENT_SENSITIVITY",
+    "ADMINISTER",
     "ALGORITHM",
     "ALLOW_CONNECTIONS",
     "ALLOW_ENCRYPTED_VALUE_MODIFICATIONS",
@@ -521,8 +524,10 @@ UNRESERVED_KEYWORDS = [
     "APPLY",
     "ARITHABORT",
     "ARITHIGNORE",
+    "ASSEMBLY",
     "ATTACH",
     "ATTACH_REBUILD_LOG",
+    "AUTHENTICATE",
     "AUTO_CLOSE",
     "AUTO_CREATE_STATISTICS",
     "AUTO_CREATE_TABLE",
@@ -546,6 +551,7 @@ UNRESERVED_KEYWORDS = [
     "CHECK_EXPIRATION",
     "CHECK_POLICY",
     "CODEPAGE",
+    "COLLECTION",
     "COLUMN_ENCRYPTION_KEY",
     "COLUMNSTORE_ARCHIVE",
     "COLUMNSTORE",
@@ -670,6 +676,7 @@ UNRESERVED_KEYWORDS = [
     "IGNORE_DUP_KEY",
     "IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX",
     "IGNORE_TRIGGERS",
+    "IMPERSONATE",
     "IMPLICIT_TRANSACTIONS",
     "INBOUND",
     "INCLUDE_NULL_VALUES",
@@ -682,9 +689,16 @@ UNRESERVED_KEYWORDS = [
     "INSERTED",
     "INSTEAD",
     "IO",
+    "ISJSON",
     "JSON",
     "JSON_ARRAY",
+    "JSON_ARRAYAGG",
+    "JSON_MODIFY",
     "JSON_OBJECT",
+    "JSON_OBJECTAGG",
+    "JSON_PATH_EXISTS",
+    "JSON_QUERY",
+    "JSON_VALUE",
     "KB",
     "KEEP",
     "KEEPDEFAULTS",
@@ -747,6 +761,7 @@ UNRESERVED_KEYWORDS = [
     "NULLS",
     "NUMERIC_ROUNDABORT",
     "OFFSET",
+    "OLD_PASSWORD",
     "ONLINE",
     "OPENJSON",
     "OPERATION_TYPE_COLUMN_NAME",
@@ -835,6 +850,7 @@ UNRESERVED_KEYWORDS = [
     "ROWS_PER_BATCH",
     "ROWTERMINATOR",
     "S",
+    "SCALAR",
     "SCALEOUTEXECUTION",
     "SCHEMA_AND_DATA",
     "SCHEMA_ONLY",
@@ -846,6 +862,7 @@ UNRESERVED_KEYWORDS = [
     "SECRET",
     "SECURITY",
     "SELF",
+    "SEND",
     "SEQUENCE_NUMBER_COLUMN_NAME",
     "SEQUENCE_NUMBER",
     "SERDE_METHOD",
@@ -855,6 +872,7 @@ UNRESERVED_KEYWORDS = [
     "SERVICE_OBJECTIVE",
     "SETERROR",
     "SETVAR",
+    "SHOWPLAN",
     "SHOWPLAN_ALL",
     "SHOWPLAN_TEXT",
     "SHOWPLAN_XML",
@@ -875,6 +893,7 @@ UNRESERVED_KEYWORDS = [
     "STOPLIST",
     "STRING_AGG",
     "STRING_DELIMITER",
+    "SUBSCRIBE",
     "SWITCH",
     "SYNONYM",
     "SYSTEM_TIME",
@@ -902,6 +921,8 @@ UNRESERVED_KEYWORDS = [
     "UNCOMMITTED",
     "UNDEFINED",
     "UNLIMITED",
+    "UNMASK",
+    "UNSAFE",
     "UPDLOCK",
     "USE_TYPE_DEFAULT",
     "USED",
